.. currentmodule:: sardana.pool

.. _sardana-0d-overview:

=======================
0D channel overview
=======================

.. todo:: document 0D experiment channel overview

.. seealso:: 
    
    :ref:`sardana-0d-api`
        the 0D experiment channel :term:`API` 
    
    :class:`~sardana.tango.pool.ZeroDExpChannel.ZeroDExpChannel`
        the 0D experiment channel tango device :term:`API`
